@@ -11,7 +11,7 @@ MainWindow::MainWindow(QWidget *parent) :
     ui(new Ui::MainWindow),
     plugin(PLUGINPATH)
 {
-    qDebug() << "TweakFlashVer v0.3";
+    qDebug() << "TweakFlashVer v0.4";
 
     settings = new QSettings("tweakflashver", "main");
     ui->setupUi(this);
@@ -26,59 +26,26 @@ MainWindow::MainWindow(QWidget *parent) :
         settings->setValue("pluginpath", PLUGINPATH);
         settings->setValue("pluginsize", PLUGINSIZE);
         settings->endGroup();
+
 #ifdef Q_WS_MAEMO5
-        settings->beginGroup("Android, 10.1.61 (FroYo)");
-        settings->setValue("part1","10.1 r61");
-        settings->setValue("part2","AND 10,1,61,0");
-        settings->setValue("index", 4);
-        settings->endGroup();
-        settings->beginGroup("Linux, 10.1.53 (Desktop)");
-        settings->setValue("part1","10.1 r53");
-        settings->setValue("part2","LNX 10,1,53,0");
-        settings->setValue("index", 3);
-        settings->endGroup();
-        settings->beginGroup("Linux, 10.0.45 (Desktop) - recommended");
-        settings->setValue("part1","10.0 r45");
-        settings->setValue("part2","LNX 10,0,45,0");
-        settings->setValue("index", 2);
-        settings->endGroup();
-        settings->beginGroup("Linux, 9.0.246 (PR1.1)");
-        settings->setValue("part1","9.0 r246");
-        settings->setValue("part2","LNX 9,0,246,0");
-        settings->setValue("index", 1);
-        settings->endGroup();
-        settings->beginGroup("Linux, 9.0.260 (PR1.2)");
-        settings->setValue("part1","9.0 r260");
-        settings->setValue("part2","LNX 9,0,260,0");
-        settings->setValue("index", 0);
-        settings->endGroup();
+        qDebug() << "Fremantle";
+    #ifdef QT_VERSION >= 0x040700
+        QSettings rcsettings(":/ini/fremantle_pr13.ini");
+    #else
+        QSettings rcsettings(":/ini/fremantle_pr12.ini");
+    #endif
 #else
-        settings->beginGroup("Android, 10.1.9");
-        settings->setValue("part1","10.1 r9");
-        settings->setValue("part2","AND 10,1,9,0");
-        settings->setValue("index", 4);
-        settings->endGroup();
-        settings->beginGroup("Linux, 10.1.9 (Desktop)");
-        settings->setValue("part1","10.1 r9");
-        settings->setValue("part2","LNX 10,1,9,0");
-        settings->setValue("index", 3);
-        settings->endGroup();
-        settings->beginGroup("Linux, 10.0.9 (Desktop) - recommended");
-        settings->setValue("part1","10.0 r9");
-        settings->setValue("part2","LNX 10,0,9,0");
-        settings->setValue("index", 2);
-        settings->endGroup();
-        settings->beginGroup("Linux, 9.0.99 (Desktop)");
-        settings->setValue("part1","9.0 r99");
-        settings->setValue("part2","LNX 9,0,99,0");
-        settings->setValue("index", 1);
-        settings->endGroup();
-        settings->beginGroup("Linux, 9.0.48 (N810 Diablo)");
-        settings->setValue("part1","9.0 r48");
-        settings->setValue("part2","LNX 9,0,48,0");
-        settings->setValue("index", 0);
-        settings->endGroup();
+        QSettings rcsettings(":/ini/diablo.ini");
 #endif
+        foreach (QString group, rcsettings.childGroups())
+        {
+            rcsettings.beginGroup(group);
+            foreach (QString key, rcsettings.allKeys())
+            {
+                settings->setValue(key, rcsettings.value(key));
+            }
+            rcsettings.endGroup();
+        }
         settings->sync();
         qDebug() << "Default settings saved";
         loadFlashVers();
@@ -94,7 +61,7 @@ MainWindow::MainWindow(QWidget *parent) :
     }
     else if (plugin.size() != settings->value("pluginsize", PLUGINSIZE).toUInt())
     {
-        QMessageBox::critical(this, tr("Error"), tr("Flash plugin file size mismatch"));
+        QMessageBox::critical(this, tr("Error"), tr("Flash plugin file size mismatch (%0 vs %1)").arg(plugin.size()).arg(settings->value("pluginsize", PLUGINSIZE).toUInt()));
         qApp->quit();
     }
     settings->endGroup();
@@ -108,6 +75,11 @@ MainWindow::MainWindow(QWidget *parent) :
     setManualMode(ui->checkBox->isChecked());
 }
 
+void MainWindow::on_actionWhy_triggered()
+{
+    QMessageBox::information(this, tr("Why you shouldn't pick the highest available version"), tr("The recommended is Linux 10.0 as that's the closest version to the one actually in the firmware (least chance of the site serving us with content we don't know how to interpret) and the one that usually is enough to pass 'requires Flash 10' checks. In reality, you will want to set the LOWEST version that will enable a site."));
+}
+
 void MainWindow::readFlashVer()
 {
     if ( plugin.open(QIODevice::ReadOnly) && plugin.seek(OFFSET2)  )
@@ -179,14 +151,9 @@ void MainWindow::changeVer()
     {
         QMessageBox::information(this, tr("Success"), tr("New version info successfully written, restarting browser daemon."));
         QStringList param;
-#ifdef Q_WS_MAEMO_5
         param << "tablet-browser-daemon";
         QProcess::execute("/usr/sbin/stop", param);
         QProcess::execute("/usr/sbin/start", param);
-#else
-        param << "restart";
-        QProcess::execute("/etc/init.d/tablet-browser-daemon", param);
-#endif
     }
     else
     {
